@@ -1,8 +1,7 @@
-from clustaar.schemas.v1 import SEND_EMAIL_ACTION
-from clustaar.schemas.models import SendEmailAction
-from lupin.errors import InvalidDocument, InvalidMatch
-
 import pytest
+from clustaar.schemas.models import SendEmailAction
+from clustaar.schemas.v1 import SEND_EMAIL_ACTION
+from lupin.errors import InvalidDocument
 
 
 @pytest.fixture
@@ -13,11 +12,27 @@ def action():
         recipient="test@example.com",
         subject="Hello",
         content=":)",
+        reply_to_email="john.doe@gmail.com",
+        reply_to_name="John Doe",
     )
 
 
 @pytest.fixture
 def data():
+    return {
+        "type": "send_email_action",
+        "fromEmail": "tintin@gmail.com",
+        "fromName": "Tintin",
+        "recipient": "test@example.com",
+        "subject": "Hello",
+        "content": ":)",
+        "replyToEmail": "john.doe@gmail.com",
+        "replyToName": "John Doe",
+    }
+
+
+@pytest.fixture
+def data_without_reply_to():
     return {
         "type": "send_email_action",
         "fromEmail": "tintin@gmail.com",
@@ -55,6 +70,8 @@ class TestLoad:
         assert action.recipient == "test@example.com"
         assert action.from_email == "tintin@gmail.com"
         assert action.from_name == "Tintin"
+        assert action.reply_to_name == "John Doe"
+        assert action.reply_to_email == "john.doe@gmail.com"
 
     def test_returns_an_action_malicious(self, malicious_data, mapper):
         action = mapper.load(malicious_data, SEND_EMAIL_ACTION)
@@ -65,6 +82,12 @@ class TestLoad:
         assert action.from_email == "tintin@gmail.com"
         assert action.from_name == "Tintin"
 
+    def test_returns_an_action_without_reply_to(self, data_without_reply_to, mapper):
+        action = mapper.load(data_without_reply_to, SEND_EMAIL_ACTION)
+        assert isinstance(action, SendEmailAction)
+        assert action.reply_to_name is None
+        assert action.reply_to_email is None
+
 
 class TestValidate:
     def test_raises_if_from_email_contains_clustaar_domain(self, data, mapper):
@@ -89,3 +112,8 @@ class TestValidate:
         data["fromEmail"] = ""
         data["fromName"] = ""
         mapper.validate(data, SEND_EMAIL_ACTION)
+
+    def test_do_not_raise_error_if_reply_to_email_is_empty(self, data, mapper):
+        data["replyToEmail"] = ""
+        data["replyToName"] = ""
+        mapper.validate(data, SEND_EMAIL_ACTION)
